==> qtjambi-debuginfo-windows-x64-6.5.4.jar: sources/QtJambiGui/QX11Application_shell.cpp <==
#include <QtCore/QtGlobal>
#if __has_include(<QtGui/qguiapplication_platform.h>)
#include <QtGui/qguiapplication_platform.h>
#endif
#include <QtCore/QVariant>
#include <QtGui/QGuiApplication>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/CoreAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

#if QT_CONFIG(xcb)



#endif // QT_CONFIG(xcb)

// emitting (writeConstructors)
// emitting  (functionsInTargetLang writeFinalFunction)
// QNativeInterface::QX11Application::connection()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_nativeinterface_QX11Application_00024Impl_00024ConcreteWrapper_connection_1native_1constfct__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(xcb)
        const QNativeInterface::QX11Application *__qt_this = QtJambiAPI::interfaceFromNativeId<QNativeInterface::QX11Application>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QNativeInterface::QX11Application::connection()const", __qt_this)
        xcb_connection_t* __qt_return_value = __qt_this->connection();
        __java_return_value = QtJambiAPI::convertNativeToQNativePointer(__jni_env, __qt_return_value, QNativePointer::Type::Pointer, 1);
#else
        Q_UNUSED(__this_nativeId)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(xcb)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QNativeInterface::QX11Application::display()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_nativeinterface_QX11Application_00024Impl_00024ConcreteWrapper_display_1native_1constfct__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(xcb)
        const QNativeInterface::QX11Application *__qt_this = QtJambiAPI::interfaceFromNativeId<QNativeInterface::QX11Application>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QNativeInterface::QX11Application::display()const", __qt_this)
        Display* __qt_return_value = __qt_this->display();
        __java_return_value = QtJambiAPI::convertNativeToQNativePointer(__jni_env, __qt_return_value, QNativePointer::Type::Pointer, 1);
#else
        Q_UNUSED(__this_nativeId)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(xcb)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QNativeInterface_QX11Application(){
    using namespace RegistryAPI;

#if QT_CONFIG(xcb)

    const std::type_info& typeId = registerInterfaceTypeInfo<QNativeInterface::QX11Application>("QNativeInterface::QX11Application", "io/qt/gui/nativeinterface/QX11Application");
    registerNativeInterface<QNativeInterface::QX11Application>("io/qt/gui/nativeinterface/QX11Application");
// BEGIN: function table
    registerConstructorInfos(typeId, nullptr, {
    });
// END: function table

// BEGIN: type registration
// END: type registration

// BEGIN: polymorphic ids
    registerPolymorphyHandler(typeid(QObject), typeId, [](void *ptr, qintptr& offset) -> bool {
            QObject *object = reinterpret_cast<QObject *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QNativeInterface::QX11Application* _object = dynamic_cast<QNativeInterface::QX11Application*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerPolymorphyHandler(typeId, typeid(QObject), [](void *ptr, qintptr& offset) -> bool {
            QNativeInterface::QX11Application *object = reinterpret_cast<QNativeInterface::QX11Application *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QObject* _object = dynamic_cast<QObject*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerOwnerFunction(typeId, [](const void *ptr)->const QObject*{
        const QNativeInterface::QX11Application *object = reinterpret_cast<const QNativeInterface::QX11Application *>(ptr);
        const QObject* _result = nullptr;
        QTJAMBI_TRY_ANY {
            _result = dynamic_cast<const QObject*>(object);
        } QTJAMBI_CATCH_ANY{
        } QTJAMBI_TRY_END
        return _result;
    });
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags

#else //QT_CONFIG(xcb)

    registerNativeInterface("io/qt/gui/nativeinterface/QX11Application", {});

#endif //QT_CONFIG(xcb)

}

==> qtjambi-debuginfo-windows-x64-6.6.3.jar: sources/QtJambiGui/QX11Application_shell.cpp <==
#include <QtCore/QtGlobal>
#if __has_include(<QtGui/qguiapplication_platform.h>)
#include <QtGui/qguiapplication_platform.h>
#endif
#include <QtCore/QVariant>
#include <QtGui/QGuiApplication>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/CoreAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

#if QT_CONFIG(xcb)



#endif // QT_CONFIG(xcb)

// emitting (writeConstructors)
// emitting  (functionsInTargetLang writeFinalFunction)
// QNativeInterface::QX11Application::connection()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_nativeinterface_QX11Application_00024Impl_00024ConcreteWrapper_connection_1native_1constfct__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(xcb)
        const QNativeInterface::QX11Application *__qt_this = QtJambiAPI::interfaceFromNativeId<QNativeInterface::QX11Application>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QNativeInterface::QX11Application::connection()const", __qt_this)
        xcb_connection_t* __qt_return_value = __qt_this->connection();
        __java_return_value = QtJambiAPI::convertNativeToQNativePointer(__jni_env, __qt_return_value, QNativePointer::Type::Pointer, 1, 1);
#else
        Q_UNUSED(__this_nativeId)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(xcb)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QNativeInterface::QX11Application::display()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_nativeinterface_QX11Application_00024Impl_00024ConcreteWrapper_display_1native_1constfct__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(xcb)
        const QNativeInterface::QX11Application *__qt_this = QtJambiAPI::interfaceFromNativeId<QNativeInterface::QX11Application>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QNativeInterface::QX11Application::display()const", __qt_this)
        Display* __qt_return_value = __qt_this->display();
        __java_return_value = QtJambiAPI::convertNativeToQNativePointer(__jni_env, __qt_return_value, QNativePointer::Type::Pointer, 1, 1);
#else
        Q_UNUSED(__this_nativeId)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(xcb)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QNativeInterface_QX11Application(){
    using namespace RegistryAPI;

#if QT_CONFIG(xcb)

    const std::type_info& typeId = registerInterfaceTypeInfo<QNativeInterface::QX11Application>("QNativeInterface::QX11Application", "io/qt/gui/nativeinterface/QX11Application");
    registerNativeInterface<QNativeInterface::QX11Application>("io/qt/gui/nativeinterface/QX11Application");
// BEGIN: function table
    registerConstructorInfos(typeId, nullptr, {
    });
// END: function table

// BEGIN: type registration
// END: type registration

// BEGIN: polymorphic ids
    registerPolymorphyHandler(typeid(QObject), typeId, [](void *ptr, qintptr& offset) -> bool {
            QObject *object = reinterpret_cast<QObject *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QNativeInterface::QX11Application* _object = dynamic_cast<QNativeInterface::QX11Application*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerPolymorphyHandler(typeId, typeid(QObject), [](void *ptr, qintptr& offset) -> bool {
            QNativeInterface::QX11Application *object = reinterpret_cast<QNativeInterface::QX11Application *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QObject* _object = dynamic_cast<QObject*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerOwnerFunction(typeId, [](const void *ptr)->const QObject*{
        const QNativeInterface::QX11Application *object = reinterpret_cast<const QNativeInterface::QX11Application *>(ptr);
        const QObject* _result = nullptr;
        QTJAMBI_TRY_ANY {
            _result = dynamic_cast<const QObject*>(object);
        } QTJAMBI_CATCH_ANY{
        } QTJAMBI_TRY_END
        return _result;
    });
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags

#else //QT_CONFIG(xcb)

    registerNativeInterface("io/qt/gui/nativeinterface/QX11Application", {});

#endif //QT_CONFIG(xcb)

}
